@@ -836,9 +836,11 @@ sub _set_var_type {
         }));
     }
     elsif ($vartype eq 'ARRAY') {
+        return if tied @{$varref};
         tie @{$varref}, 'Dios::Types::Pure::TypedArray', [$type, $value_desc, @constraint];
     }
     elsif ($vartype eq 'HASH') {
+        return if tied %{$varref};
         tie %{$varref}, 'Dios::Types::Pure::TypedHash',  [$type, $value_desc, @constraint];
     }
     else {
